<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Prime Spa
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'prime-spa' ); ?></a>
		<div class="topHeader">
			<div class="topHeaderSection">
				<div class="col-2">
					<?php 
					if ( get_theme_mod( 'email' ) <> '' ) {
						echo '<i class="fa fa-envelope"></i> <a href="mailto:' . esc_attr( get_theme_mod( 'email' ) ) . '" class="top-email">' . esc_html( get_theme_mod( 'email' ) ) . '</a> |&nbsp; ';
					}
					if ( get_theme_mod( 'phone' ) <> '' ) {
						echo '<i class="fa fa-phone"></i> <a href="tel:' . esc_attr( get_theme_mod( 'phone' ) ) . '" class="top-phone">' . esc_html( get_theme_mod( 'phone' ) ) . '</a>';
					}
					?>
				</div>
				<div class="col-2">
				<?php
				prime_spa_social_links();
				?>
				</div>
			</div>
		</div>

	<header id="myHeader" class="site-header">
		<div class="mainNavbar">
			<?php
			if ( has_custom_logo() ) {
				prime_spa_logo();
			}
			?>
			<span class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></span>
			<nav id="site-navigation" class="main-navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
			<span class="screen-reader-text"><?php esc_html_e( 'Primary Menu', 'prime-spa' ); ?></span><i class="fa fa-plus"></i>
			</button>
			<?php
			wp_nav_menu(
				array(
					'theme_location' => 'menu-1',
					'menu_id'        => 'primary-menu',
				)
			);
			?>
		</nav><!-- #site-navigation -->

	</header><!-- #masthead -->

	<div class="content">
		<section class="bannerSection">
			<?php
			if ( is_singular() ) {
				the_title( '<h1>', '</h1>' );
			} elseif ( is_404() ) {
				echo '<h1>' . esc_html__( '404', 'prime-spa' ) . '</h1>';
			} elseif ( is_search() ) {
				echo '<h1>';
				/* translators: %s: search query. */
				printf( esc_html__( 'Search Results for: %s', 'prime-spa' ), '<span>' . get_search_query() . '</span>' );
				echo '</h1>';
			} elseif ( is_archive() ) {
				the_archive_title( '<h1 class="page-title">', '</h1>' );
			} elseif ( get_theme_mod( 'header_text_heading', '' ) <> '' ) {
				echo '<h1>' . esc_html( get_theme_mod( 'header_text_heading' ) ) . '</h1>';
			}

			if ( get_theme_mod( 'show_breadcrumbs', true ) === true ) {
				?>
				<div class="breadcrumbs">
					<?php prime_spa_breadcrumb_trail(); ?>
				</div>
				<?php
			}
			?>
		</section>
