<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package Prime Spa
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function prime_spa_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Adds a class of no-sidebar when there is no sidebar present.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	if ( get_theme_mod( 'email' ) <> '' ||
		get_theme_mod( 'phone' ) <> '' ||
		get_theme_mod( 'facebook_link', '' ) <> '' ||
		get_theme_mod( 'twitter_link', '' ) <> '' ||
		get_theme_mod( 'instagram_link', '' ) <> '' ||
		get_theme_mod( 'linkedin_link', '' ) <> '' ||
		get_theme_mod( 'youtube_link', '' ) <> '' ||
		get_theme_mod( 'pinterest_link', '' ) <> '' ) {
		$classes[] = 'has-top-bar';
	}

	return $classes;
}
add_filter( 'body_class', 'prime_spa_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function prime_spa_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'prime_spa_pingback_header' );

/**
 * Custom styles. See customizer-typography for typography styles.
 */
function prime_spa_custom_styles() {
	echo '<style type="text/css">';

	if ( get_theme_mod( 'container_width', 100 ) !== 100 ) {
		echo '@media screen and (min-width: 600px) {';
		echo '.site { width:' . esc_attr( get_theme_mod( 'container_width', 100 ) ) . '%; margin: 0 auto; }';
		echo '}';
	}

	if ( get_theme_mod( 'enable_mobile_logo', false ) !== false && ! empty( get_theme_mod( 'mobile_logo' ) ) ) {
		echo '@media screen and (max-width: 767px) {';
		echo '.custom-logo-link{ display: none; }';
		echo '}';
		echo '@media screen and (min-width: 767px) {';
		echo '.mobile-custom-logo-link{ display: none; }';
		echo '}';
	}

	echo '</style>';

}
add_action( 'wp_head', 'prime_spa_custom_styles' );

/***
 * Basic support for a custom mobile logo.
 */
function prime_spa_logo() {

	if ( has_custom_logo() ) {
		the_custom_logo();
	}

	if ( get_theme_mod( 'enable_mobile_logo', false ) !== false && ! empty( get_theme_mod( 'mobile_logo' ) ) ) {
		echo '<a href="' . esc_url( home_url( '/' ) ) . '" class="mobile-custom-logo-link" rel="home">';
		echo '<img src ="' . esc_url( get_theme_mod( 'mobile_logo' ) ) . '" alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" class="custom-logo"';
		echo '</a>';
	}

}

/**
 * Add the dropdown arrow to links with submenus.
 *
 * @param string   $item_output The menu item's starting HTML output.
 * @param WP_Post  $item        Menu item data object.
 * @return string
 */
add_filter( 'walker_nav_menu_start_el', function( $item_output, $item ) {
	$has_children = in_array( 'menu-item-has-children', $item->classes );
	if ( $has_children ) {
		$item_output = str_replace(
			'</a>',
			'<i class="fa fa-angle-down"></i></a>',
			$item_output
		);
	}
	return $item_output;
}, 10, 2 );

