<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Prime Spa
 */

if ( ! function_exists( 'prime_spa_posted_on' ) ) :
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 */
	function prime_spa_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( DATE_W3C ) ),
			esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			/* translators: %s: post date. */
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);

		echo ' <span class="posted-on">' . $posted_on . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'prime_spa_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 */
	function prime_spa_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'Posted by %s', 'post author', 'prime-spa' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span> '; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'prime_spa_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the tags and comments.
	 */
	function prime_spa_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'prime-spa' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'prime-spa' ) . '</span>', $tags_list ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'prime-spa' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					wp_kses_post( get_the_title() )
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit <span class="screen-reader-text">%s</span>', 'prime-spa' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				wp_kses_post( get_the_title() )
			),
			'<span class="edit-link">',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;

if ( ! function_exists( 'prime_spa_social_links' ) ) {
	function prime_spa_social_links() {
		if ( get_theme_mod( 'facebook_link', '' ) <> '' ||
			get_theme_mod( 'twitter_link', '' ) <> '' ||
			get_theme_mod( 'instagram_link', '' ) <> '' ||
			get_theme_mod( 'linkedin_link', '' ) <> '' ||
			get_theme_mod( 'youtube_link', '' ) <> '' ||
			get_theme_mod( 'pinterest_link', '' ) <> ''
		) {
			?>
			<ul class="social-links">
			<?php

			if ( get_theme_mod( 'facebook_link', '' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'facebook_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'Facebook', 'prime-spa' ); ?></span><i class="fab fa-facebook"></i></a></li>
				<?php
			}

			if ( get_theme_mod( 'twitter_link', '' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'twitter_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'Twitter', 'prime-spa' ); ?></span><i class="fab fa-twitter"></i></a></li>
				<?php
			}

			if ( get_theme_mod( 'instagram_link', '' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'instagram_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'Instagram', 'prime-spa' ); ?></span><i class="fab fa-instagram"></i></a></li>
				<?php
			}

			if ( get_theme_mod( 'linkedin_link','' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'linkedin_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'LinkedIn', 'prime-spa' ); ?></span><i class="fab fa-linkedin"></i></a></li>
				<?php
			}

			if ( get_theme_mod( 'youtube_link', '' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'youtube_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'YouTube', 'prime-spa' ); ?></span><i class="fab fa-youtube"></i></a></li>
				<?php
			}

			if ( get_theme_mod( 'pinterest_link', '' ) <> '' ) {
				?>
				<li><a href="<?php echo esc_url( get_theme_mod( 'pinterest_link' ) ); ?>"><span class="screen-reader-text"><?php esc_html_e( 'Pinterest', 'prime-spa' ); ?></span><i class="fab fa-pinterest"></i></a></li>
				<?php
			}

			?>
			</ul>
			<?php
		}
	}
}
